# -*- coding: utf-8 -*-

"""
Export details of a Beaker task
===============================

.. program:: bkr task-details

Synopsis
--------

:program:`bkr task-details` [*options*] <task>...

Description
-----------

Prints to stdout details about each of the given tasks from Beaker's task 
library, one task per line.

This information is also available on the task page in the Beaker web UI.

Options
-------

.. option:: --invalid

   Print invalid task detail.

Common :program:`bkr` options are described in the :ref:`Options 
<common-options>` section of :manpage:`bkr(1)`.

Exit status
-----------

Non-zero on error, otherwise zero.

Examples
--------

Fetch details of the /distribution/beaker/dogfood task::

    bkr task-details /distribution/beaker/dogfood

See also
--------

:manpage:`bkr(1)`
"""


from bkr.client.task_watcher import *
from bkr.client import BeakerCommand
from optparse import OptionValueError
import sys
import os.path
import xmlrpclib
from xml.dom.minidom import Document, parseString

class Task_Details(BeakerCommand):
    """Show details about Task"""
    enabled = True

    def options(self):
        self.parser.usage = "%%prog %s [options] ..." % self.normalized_name
        self.parser.add_option(
            "--xml",
            default=False,
            action="store_true",
            help="print as xml",
        )
        self.parser.add_option(
            "--invalid",
            default=False,
            action="store_true",
            help="show invalid task",
        )

    def run(self, *args, **kwargs):
        filter = dict()
        username = kwargs.pop("username", None)
        password = kwargs.pop("password", None)
        xml = kwargs.pop("xml")
        valid = True
        if kwargs.get("invalid"):
            valid = None

        self.set_hub(username, password)
        for task in args:
            print "%s %s" % (task, self.hub.tasks.to_dict(task,valid))
